==> cat-components-1.9.7.tgz: package/lib/bin/copy.js <==
#!/usr/bin/env node

'use strict';

require('babel-polyfill');

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _process = require('process');

var _process2 = _interopRequireDefault(_process);

var _memFs = require('mem-fs');

var _memFs2 = _interopRequireDefault(_memFs);

var _memFsEditor = require('mem-fs-editor');

var _memFsEditor2 = _interopRequireDefault(_memFsEditor);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _inquirer = require('inquirer');

var _inquirer2 = _interopRequireDefault(_inquirer);

var _copy = require('./core/copy');

var _copy2 = _interopRequireDefault(_copy);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

var targetRootPath = _process2.default.cwd();
var templateFolder = _path2.default.resolve(__dirname, './../../temp');

_asyncToGenerator(regeneratorRuntime.mark(function _callee() {
  var _ref2, template, targetPath, result;

  return regeneratorRuntime.wrap(function _callee$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          _context.prev = 0;
          _context.next = 3;
          return _inquirer2.default.prompt([{
            type: 'list',
            name: 'template',
            message: 'Choose you need',
            choices: _fs2.default.readdirSync(templateFolder).reduce(function (choices, folderName) {
              return choices.concat(_fs2.default.readdirSync(_path2.default.resolve(templateFolder, folderName)).reduce(function (items, itemName) {
                if (['style', 'temp'].includes(itemName)) return items;

                return items.concat(['[' + folderName + '] ' + itemName]);
              }, []));
            }, [])
          }, {
            name: 'targetPath',
            message: 'Give a root path',
            default: './src/components',
            validate: function validate(target) {
              return _fs2.default.existsSync(_path2.default.resolve(targetRootPath, target)) ? true : 'The folder does not exist.';
            },
            filter: function filter(target) {
              return _path2.default.resolve(targetRootPath, target);
            }

          }]);

        case 3:
          _ref2 = _context.sent;
          template = _ref2.template;
          targetPath = _ref2.targetPath;
          _context.next = 8;
          return (0, _copy2.default)(template, targetPath);

        case 8:
          result = _context.sent;


          result.forEach(function (_ref3) {
            var target = _ref3.target,
                template = _ref3.template;

            var store = _memFs2.default.create();
            var fs = _memFsEditor2.default.create(store);

            fs.copy(template, target);

            fs.commit(function (err) {
              if (err) throw new Error(err);

              console.log(_chalk2.default.green('build ') + _chalk2.default.cyan(target.replace(_process2.default.cwd() + '/', '')));
            });
          });
          _context.next = 15;
          break;

        case 12:
          _context.prev = 12;
          _context.t0 = _context['catch'](0);
          throw new Error(_context.t0);

        case 15:
        case 'end':
          return _context.stop();
      }
    }
  }, _callee, undefined, [[0, 12]]);
}))();

==> cat-components-1.9.11.tgz: package/lib/bin/copy.js <==
#!/usr/bin/env node

'use strict';

require('babel-polyfill');

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _process = require('process');

var _process2 = _interopRequireDefault(_process);

var _memFs = require('mem-fs');

var _memFs2 = _interopRequireDefault(_memFs);

var _memFsEditor = require('mem-fs-editor');

var _memFsEditor2 = _interopRequireDefault(_memFsEditor);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _inquirer = require('inquirer');

var _inquirer2 = _interopRequireDefault(_inquirer);

var _copy = require('./core/copy');

var _copy2 = _interopRequireDefault(_copy);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

var targetRootPath = _process2.default.cwd();
var templateFolder = _path2.default.resolve(__dirname, './../../temp');

_asyncToGenerator(regeneratorRuntime.mark(function _callee() {
  var _ref2, template, targetPath, result;

  return regeneratorRuntime.wrap(function _callee$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          _context.prev = 0;
          _context.next = 3;
          return _inquirer2.default.prompt([{
            type: 'list',
            name: 'template',
            message: 'Choose you need',
            choices: _fs2.default.readdirSync(templateFolder).reduce(function (choices, folderName) {
              return [].concat(_toConsumableArray(choices), _toConsumableArray(_fs2.default.readdirSync(_path2.default.resolve(templateFolder, folderName)).reduce(function (items, itemName) {
                if (['style', 'temp'].includes(itemName)) return items;

                return [].concat(_toConsumableArray(items), ['[' + folderName + '] ' + itemName]);
              }, [])));
            }, [])
          }, {
            name: 'targetPath',
            message: 'Give a root path',
            default: './src/components',
            validate: function validate(target) {
              return _fs2.default.existsSync(_path2.default.resolve(targetRootPath, target)) ? true : 'The folder does not exist.';
            },
            filter: function filter(target) {
              return _path2.default.resolve(targetRootPath, target);
            }

          }]);

        case 3:
          _ref2 = _context.sent;
          template = _ref2.template;
          targetPath = _ref2.targetPath;
          _context.next = 8;
          return (0, _copy2.default)(template, targetPath);

        case 8:
          result = _context.sent;


          result.forEach(function (_ref3) {
            var target = _ref3.target,
                template = _ref3.template;

            var store = _memFs2.default.create();
            var fs = _memFsEditor2.default.create(store);

            fs.copy(template, target);

            fs.commit(function (err) {
              if (err) throw new Error(err);

              console.log(_chalk2.default.green('build ') + _chalk2.default.cyan(target.replace(_process2.default.cwd() + '/', '')));
            });
          });
          _context.next = 15;
          break;

        case 12:
          _context.prev = 12;
          _context.t0 = _context['catch'](0);
          throw new Error(_context.t0);

        case 15:
        case 'end':
          return _context.stop();
      }
    }
  }, _callee, undefined, [[0, 12]]);
}))();
